@@ -1,21 +1,27 @@
 import os, sys
-from typing import NamedTuple, Union, List, Sequence, Any, Dict
+# from typing import NamedTuple, Union, List, Sequence, Any, Dict
+import typing
 import scipy.io
 import numpy as np
 
-from d3m_metadata.container.numpy import ndarray
-from d3m_metadata import hyperparams, params
+# from d3m_metadata.container.numpy import ndarray
+# from d3m_metadata import hyperparams, params
+from d3m_metadata import container, hyperparams, metadata as metadata_module, params, utils
 from primitive_interfaces.supervised_learning import SupervisedLearnerPrimitiveBase
+from . import __version__
+
 
 import rpi_feature_selection_toolbox
 
 
-Inputs = ndarray
-Outputs = ndarray
+Inputs = container.ndarray
+Outputs = container.ndarray
 
-class Params(params.Params):
-    n_features: int
-    feature_index: ndarray
+__all__ = ('IPCMBplus_Selector',)
+
+# class Params(params.Params):
+#     n_features: int
+#     feature_index: ndarray
 
 
 class Hyperparams(hyperparams.Hyperparams):
@@ -29,29 +35,57 @@ class Hyperparams(hyperparams.Hyperparams):
 
 
 class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
-    __author__ = "RPI TA1 Performers"
-    __metadata__ = {
-        "team": "RPI DARPA D3M TA1 team",
-        "common_name": "Structured Feature Selection",
-        "algorithm_type": ["Dimensionality Reduction"],
-        "task_type": ["Feature Selection"],
-        "compute_resources": {
-            "sample_size": [],
-            "sample_unit": [],
-            "disk_per_node": [],
-            "expected_running_time": [],
-            "gpus_per_node": [],
-            "cores_per_node": [],
-            "mem_per_gpu": [],
-            "mem_per_node": [],
-            "num_nodes": [],
-        },
-        "learning_type": ["Supervised Learning"],
-        "handles_regression": False,
-        "handles_classification": False,
-        "handles_multiclass": False,
-        "handles_multilabel": False,
-    }
+    # __author__ = "RPI TA1 Performers"
+    # __metadata__ = {
+    #     "team": "RPI DARPA D3M TA1 team",
+    #     "common_name": "Structured Feature Selection",
+    #     "algorithm_type": ["Dimensionality Reduction"],
+    #     "task_type": ["Feature Selection"],
+    #     "compute_resources": {
+    #         "sample_size": [],
+    #         "sample_unit": [],
+    #         "disk_per_node": [],
+    #         "expected_running_time": [],
+    #         "gpus_per_node": [],
+    #         "cores_per_node": [],
+    #         "mem_per_gpu": [],
+    #         "mem_per_node": [],
+    #         "num_nodes": [],
+    #     },
+    #     "learning_type": ["Supervised Learning"],
+    #     "handles_regression": False,
+    #     "handles_classification": False,
+    #     "handles_multiclass": False,
+    #     "handles_multilabel": False,
+    # }
+
+    metadata = metadata_module.PrimitiveMetadata({
+        'id': '69845479-0b61-3578-b382-972cd0e61d69',
+        'version': __version__,
+        'name': 'IPCMB feature selector',
+        'keywords': 'rpi primitives',
+        'source': {
+            'name': 'RPI',
+            'uris': [
+                'rpi_featureSelection_python_tools',
+                'rpi_feature_selection_toolbox'
+            ],
+        }
+        'installation':[{
+            'type': 'PIP',
+            'package_uri': 'rpi_featureSelection_python_tools'
+        }]
+        'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.IPCMBplus_Selector',
+        'algorithm_types': 'MINIMUM_REDUNDANCY_FEATURE_SELECTION',
+        'primitive_family': 'FEATURE_SELECTION',
+        'preconditions': [
+            "NO_CATEGORICAL_VALUES",
+            "NO_MISSING_VALUES"
+        ]
+    })
+
+
+
 
     def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: Dict[str, str] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed)
